/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.spi.component;

import org.fabric3.spi.ObjectFactory;


/**
 * Provides lifecycle management for an implementation instance associated with an {@link
 * org.fabric3.spi.component.AtomicComponent} for use by the atomic component's associated {@link
 * org.fabric3.spi.component.ScopeContainer}
 *
 * @version $Rev: 3107 $ $Date: 2008-03-15 10:44:05 -0700 (Sat, 15 Mar 2008) $
 */
public interface InstanceWrapper<T> {

    T getInstance();

    boolean isStarted();

    void start() throws TargetInitializationException;

    void stop() throws TargetDestructionException;
    
    void reinject() throws TargetResolutionException;

    void addObjectFactory(String referenceName, ObjectFactory<?> factory, Object key);

}
